copyright

# XMLRésuméLibrary: User Guide

contact | Element Reference | country

## Name

copyright — A copyright notice

## Synopsis

### Content Model

    (year,name?,legalnotice?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `copyright` element defines a copyright notice. The notice must include the year of copyright; it may also include the name of the copyright owner and a legal notice.

### Parents

`copyright` may be contained in these elements: `resume`

## Examples

    <resume>
      <copyright>
        <year>1892</year>
        <name>
          <firstname>Fluisha</firstname>
          <surname>Copenhagen</surname>
        </name>
        <legalnotice>
          <para>
            All rights reserved. This document may not be copied or distributed
            without permission.
          </para>
        </legalnotice>
      </copyright>
    </resume>

    <copyright>
      <year>2001</year>
    </copyright>

contact | Element Reference | country